README
======

Yarap is a wrapper for yattag. Simplifies creation of static html reports.
Makes navigation ultra-easy. Run pytest or tox and check the output.

======== ======================================================
resource link
======== ======================================================
Repo:    https://bitbucket.org/gandowin/yarap
Docs:    http://yawrap.readthedocs.io
Pypi:    https://pypi.python.org/pypi/yawrap
email:   `Michał Kaczmarczyk <mailto:michal.skaczmarczy.k@gmail.com?Subject=Yawrap>`_
======== ======================================================

The development status is beta: The assumed functionality works but minor things may be changed in the future.
Until the documentation is not finished, please refer directly to the code tests or code itself.

.. image:: https://readthedocs.org/projects/yawrap/badge/?version=latest
    :target: http://yawrap.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

Yawrap features
---------------

Here is a summary list of things that ``yawrap`` offers:

* CSS & JavaScript & SVG support
* Linking local files automatically apearing as relative path
* Defining page style and scripts on python class level
* Multiple-page, nested structure support
* Automatically generated navigation for each page in documents' tree
* Bookmarking
